@@ -38,7 +38,7 @@ class AmazonJob(Job):
             base_text: typing.Optional[str] = '',
             markers: typing.List[typing.Optional[Marker]] = [],
             bucket: typing.Optional[str]=None,
-            status: typing.Optional[str]=None,
+            started: bool=False,
             transcription: typing.Dict[typing.Any, typing.Any] = {},
             alternatives: typing.List[Alternative] = [],
             speakers: typing.List[Speaker] = [],
@@ -60,8 +60,8 @@ class AmazonJob(Job):
 
         self.name = self.key
 
-        if status:
-            self._status = status
+        if started:
+            self._status = 'STARTED'
 
         else:
             self._status = 'NOT STARTED'
@@ -72,8 +72,6 @@ class AmazonJob(Job):
         if self._status in ['COMPLETED', 'NOT STARTED']:
             return self._status
 
-
-
         job = transcribe.get_transcription_job(TranscriptionJobName=self.key)
         status = job['TranscriptionJob']['TranscriptionJobStatus']
 
@@ -100,6 +98,7 @@ class AmazonJob(Job):
         audio_file = self.upload_audio_file(self.filepath)
 
         transcribe_job_uri = f"{storage.meta.endpoint_url}/{self.bucket}/{self.key}"
+        print(transcribe_job_uri)
 
         if speakers:
             settings = {
@@ -125,13 +124,7 @@ class AmazonJob(Job):
     def from_job(job_name: str) -> Job:
         """Create a Job Object based on the TranscriptiobJobName"""
         job = transcribe.get_transcription_job(TranscriptionJobName=job_name)
-
-        if (status:=job['TranscriptionJob']['Status']) == 'COMPLETED':
-            return AmazonJob.from_uri(job['TranscriptionJob']['Transcript']['TranscriptFileUri'])
-
-        else:
-            return status
-
+        return AmazonJob.from_uri(job['TranscriptionJob']['Transcript']['TranscriptFileUri'])
 
     @staticmethod
     def from_uri(uri:str) -> Job:
@@ -143,10 +136,6 @@ class AmazonJob(Job):
 
     def build(self) -> Job:
         """Create a Job Object when given an Amazon JSON Object"""
-
-        if status:=self.status != 'COMPLETED':
-            return status
-
         job = transcribe.get_transcription_job(TranscriptionJobName=self.key)
         uri = job['TranscriptionJob']['Transcript']['TranscriptFileUri']
         response = requests.get(uri)
@@ -224,13 +213,76 @@ class AmazonJob(Job):
     @classmethod
     def from_json(cls, transcription) -> Job:
         """Create a Job Object when given an Amazon JSON Object"""
+        markers = []
+        segments = transcription['results']['items']
 
-        newJob = cls()
-        newJob.key = transcription['jobName'],
-        newJob.name = newJob.key
-        newJob.build()
+        if 'speaker_labels' in transcription['results']:
+            labels = transcription['results']['speaker_labels']
+            speakers = [add_speaker(x) for x in range(labels['speakers'])]
 
-        return newJob
+            for segment in labels['segments']:
+                start_time=segment['start_time']
+                end_time=segment['end_time']
+                speaker=[x for x in speakers if x.base_name == segment['speaker_label']][0]
+                content = text_in_range(
+                        segments,
+                        start_time=start_time,
+                        end_time=end_time,
+                        )
+                marker = Marker(
+                        start_time = timedelta(seconds=float(start_time)),
+                        end_time = timedelta(seconds=float(end_time)),
+                        content = content,
+                        speaker = speaker
+                        )
+                markers.append(marker)
+
+        else:
+
+            speakers = []
+
+            items_segments = more_itertools.split_when(
+                segments, lambda x,y: x['alternatives'][0]['content'] in ['.', '?', '!'],
+            )
+
+            for index, item in enumerate(items_segments):
+                start_time = timedelta(seconds=float(item[0]['start_time']))
+                end_time = timedelta(seconds=float(item[-2]['end_time']))
+                content = ''
+
+                for word_block in item:
+                    if word_block['type'] == 'punctuation':
+                        content += word_block['alternatives'][0]['content']
+                    else:
+                        content += " " + word_block['alternatives'][0]['content']
+
+                marker = Marker(start_time=start_time, end_time=end_time,
+                        content=content)
+                markers.append(marker)
+
+        # add alternatives
+        alternatives = []
+        for item in segments:
+
+            if item['type'] == 'pronunciation':
+
+                for alt in item['alternatives']:
+                    alternatives.append(Alternative(
+                        start_time = item['start_time'],
+                        content = alt['content'],
+                        confidence = alt['confidence'],
+                        tag = 'orignal',
+                        _type = 'pronunciation',
+                        ))
+
+        return cls(
+                base_text = transcription['results']['transcripts'][0]['transcript'],
+                key = transcription['jobName'],
+                transcription=transcription,
+                speakers = speakers,
+                markers = markers,
+                alternatives = alternatives,
+                )
 
 ## Download Jobs
 def text_in_range(segments, start_time, end_time):
